@@ -52,16 +52,16 @@ class MySQLEngine(_DataBaseEngine):
         database: MySQL database needed to connect to database.
     """
 
-    def __init__(self, database: str):
+    def __init__(self, source_name: str):
         # TODO: As more use cases arise, move configuration to a separate module.
 
         super().__init__()
 
-        self.host = getenv(f"MYSQL_{database}_HOST".upper())
-        self.port = int(getenv(f"MYSQL_{database}_PORT".upper(), "3306"))
-        self.user = getenv(f"MYSQL_{database}_USER".upper())
-        self.password = getenv(f"MYSQL_{database}_PASS".upper())
-        self.database = database
+        self.host = getenv(f"MYSQL_{source_name}_HOST".upper())
+        self.port = int(getenv(f"MYSQL_{source_name}_PORT".upper(), "3306"))
+        self.user = getenv(f"MYSQL_{source_name}_USER".upper())
+        self.password = getenv(f"MYSQL_{source_name}_PASS".upper())
+        self.database = getenv(f"MYSQL_{source_name}_DB".upper())
 
     def read(
         self, query: str, output_type: str = consts.output_types.PANDAS, **kwargs
@@ -96,9 +96,7 @@ class MySQLEngine(_DataBaseEngine):
         try:
             return output_type_map[output_type](query, connection, **kwargs)
         except KeyError:
-            raise TypeError(
-                f"possible output_types: {list(output_type_map.keys())}"
-            )
+            raise TypeError(f"possible output_types: {list(output_type_map.keys())}")
 
     def write(self, obj: Any):
         """
@@ -107,7 +105,9 @@ class MySQLEngine(_DataBaseEngine):
         raise NotImplementedError
 
     @staticmethod
-    def _output_pandas(query: str, connection: MySQLdb.Connection, **kwargs) -> pd.DataFrame:
+    def _output_pandas(
+        query: str, connection: MySQLdb.Connection, **kwargs
+    ) -> pd.DataFrame:
         """
         Outputs data from a MySQL query in pandas DataFrame object.
 
@@ -197,9 +197,7 @@ class GoogleBigQueryEngine(_DataBaseEngine):
         try:
             return output_type_mapper[output_type](query, self.project_id)
         except KeyError:
-            raise TypeError(
-                f"possible output_types: {list(output_type_mapper.keys())}"
-            )
+            raise TypeError(f"possible output_types: {list(output_type_mapper.keys())}")
 
     def write(self, obj: Any):
         """
@@ -241,4 +239,3 @@ class GoogleBigQueryEngine(_DataBaseEngine):
         """
 
         raise NotImplementedError
-
