@@ -9,7 +9,7 @@ class Source:
 
     Examples:
         >>> import datatosk
-        >>> source = datatosk.Source.mysql(database="db")
+        >>> source = datatosk.Source.mysql(source_name="local")
         >>> source.read("SELECT * FROM table")
            col1  col2
         0     1     3
